/*=============================================================================
vitalnix/accdb - User Management Suite - Unified Account Database
sysprog/shared.c - Shared functions for the ACCDB system utilities
  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2003
  -- License restrictions apply (Dual FAL/GPL2).
  -- For details see doc/FAL.txt and doc/GPL2.txt.
=============================================================================*/
#include <ctype.h>
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>

#include <libHX.h>
#include "sysprog/shared.h"
#define MAXLNLEN 1024 /* max length for line buffer */

typedef unsigned char byte;

//-----------------------------------------------------------------------------
int Sh_count_args(const char **args) {
    int argk = 0;
    while(*args++ != NULL) { ++argk; }
    return argk;
}

void Sh_interactive(struct itab *qtabp) {
    char buf[MAXLNLEN];

    while(qtabp->fmt != NULL) {
        if(qtabp->type == 's') {
            char **ptr = qtabp->ptr;
            printf(qtabp->fmt, (*ptr != NULL) ? *ptr : "");
            fgets(buf, MAXLNLEN, stdin);
            HX_chomp(buf);
            if(strlen(buf) > 0) { HX_strclone(ptr, buf); }
        } else if(qtabp->type == 'd') {
            int *ptr = qtabp->ptr;
            printf(qtabp->fmt, (ptr != NULL) ? *ptr : 0);
            fgets(buf, MAXLNLEN, stdin);
            HX_chomp(buf);
            if(strlen(buf) > 0) { *ptr = strtol(buf, NULL, 0); }
        }

        if(!(qtabp->callback != NULL &&
         !qtabp->callback(qtabp->fmt, qtabp->type, qtabp->ptr))) {
            ++qtabp;
        }
    }

    return;
}

long Sh_string_to_iday(char *s) {
    struct tm td;
    time_t r;
    memset(&td, 0, sizeof(struct tm));

    if(strchr(s, '.') != NULL) {
        // DD.MM.YYYY
        sscanf(s, "%d.%d.%d", &td.tm_mday, &td.tm_mon, &td.tm_year);
    } else if(strchr(s, '/') != NULL) {
        // MM/DD/YYYY
        sscanf(s, "%d/%d/%d", &td.tm_mon, &td.tm_mday, &td.tm_year);
    } else if(strchr(s, '-') != NULL) {
        // YYYY-MM-DD (ISO 8601) format
        sscanf(s, "%d-%d-%d", &td.tm_year, &td.tm_mon, &td.tm_mday);
    } else {
        return -1;
    }

    r = mktime(&td);
    if(r == -1) { return -1; }
    return (unsigned long)r / 86400;
}

int Sh_only_digits(char *p) {
  if(p == NULL) { return 0; }
  while(*p != '\0') {
    if(!isdigit(*p++)) { return 0; }
  }
  return 1;
}

//==[ End of file ]============================================================
